@@ -1,4 +1,4 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 
 =head1 NAME
 
@@ -7,6 +7,7 @@ Debconf::Element::Editor::Note - Just text to display to user.
 =cut
 
 package Debconf::Element::Editor::Note;
+use warnings;
 use strict;
 use base qw(Debconf::Element::Editor::Text);
 
