@@ -1,4 +1,4 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 
 =head1 NAME
 
@@ -7,6 +7,7 @@ Debconf::Element::Gnome::Password - password input widget
 =cut
 
 package Debconf::Element::Gnome::Password;
+use warnings;
 use strict;
 use Gtk3;
 use utf8;
@@ -46,7 +47,7 @@ If the widget's value field is empty, return the default.
 
 sub value {
 	my $this=shift;
-	
+
 	# FIXME in which encoding?
 	my $text = $this->widget->get_chars(0, -1);
 	$text = $this->question->value if $text eq '';
