@@ -1,4 +1,4 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 
 =head1 NAME
 
@@ -7,6 +7,7 @@ Debconf::Element::Gnome::String - text input widget
 =cut
 
 package Debconf::Element::Gnome::String;
+use warnings;
 use strict;
 use Gtk3;
 use utf8;
@@ -29,7 +30,7 @@ sub init {
 
 	my $default='';
 	$default=$this->question->value if defined $this->question->value;
-	
+
 	$this->widget->set_text(to_Unicode($default));
 
 	$this->adddescription;
